@@ -30,6 +30,8 @@ class BertEmbedding(TransformerEmbedding):
             else:
                 config_path = os.path.join(model_folder, 'bert_config.json')
                 checkpoint_path = os.path.join(model_folder, 'bert_model.ckpt')
+                if not os.path.exists(checkpoint_path):
+                    checkpoint_path = None
             kwargs['checkpoint_path'] = checkpoint_path
             kwargs['config_path'] = config_path
         kwargs['model_type'] = model_type
