@@ -1,4 +1,5 @@
 from tensorflow.keras.layers import Layer
+from tensorflow.keras import backend as K
 import nlp_tools
 import tensorflow as tf
 
@@ -41,5 +42,26 @@ class MaskingSaverLayer(Layer):
         return loss_
 
 
+class  HierarchicalAttentionMaskingLayer(Layer):
+    def __init__(self,input_masking=None,**kwargs):
+        self.supports_masking = True
+        self.input_masking = input_masking
+        super(HierarchicalAttentionMaskingLayer,self).__init__(**kwargs)
+
+    def build(self, input_shape):
+        pass
+
+    def compute_mask(self, inputs, mask=None):
+        # print("222")
+        # print(mask)
+        #if mask != None :
+            #mask = tf.cast(tf.reduce_sum(mask, reduction_indices=-1) > 0, tf.float32)  # sentence mask
+            #change_mask = tf.reduce_sum(tf.cast(mask,tf.int32),axis=-1)
+            #mask  = 1 - tf.cast(tf.equal(change_mask,0),tf.int32)
+            #mask = tf.cast(mask,tf.bool)
+        return K.cast(self.input_masking,tf.bool)
+    def call(self,x,mask=None):
+        return x
+
 nlp_tools.custom_objects['NonMaskingLayer'] = NonMaskingLayer
 nlp_tools.custom_objects['MaskingSaverLayer'] = MaskingSaverLayer
\ No newline at end of file
