@@ -1,6 +1,6 @@
 from tensorflow.keras.callbacks import Callback
 import numpy as np
-from sklearn.metrics import f1_score,classification_report,confusion_matrix
+from sklearn.metrics import f1_score
 
 class F1CategoryCallback(Callback):
     def __init__(self,model_check,model_save_path,valid_data,batch_size=32):
@@ -16,8 +16,6 @@ class F1CategoryCallback(Callback):
     def caculate_f1(self):
         predict_labels  = self.model_check.predict(self.valid_x,batch_size=self.batch_size)
         f1_score_value = f1_score(self.valid_y,predict_labels,average='macro')
-        print(classification_report(self.valid_y,predict_labels))
-        print(confusion_matrix(self.valid_y,predict_labels,labels=['不是',"不确定","是"]))
 
         return f1_score_value
 
@@ -30,7 +28,7 @@ class F1CategoryCallback(Callback):
             self.model_check.save(self.model_save_path)
             self.count = 0
         self.count += 1
-        if self.count >15:
+        if self.count >10:
             self.model.stop_training = True
             self.count = 0
         print(
