@@ -1,12 +1,13 @@
-import os
-import json
+import random
 from abc import ABC
+import numpy as np
 from typing import List,Dict,Any,Union
+
 from sklearn import metrics as sklearn_metrics
 
 import nlp_tools
 from nlp_tools.layers import L
-
+from nlp_tools.logger import logger
 
 from nlp_tools.tasks.abs_task_model import ABCTaskModel
 from nlp_tools.types import TextSamplesVar,ClassificationLabelVar,MultiLabelClassificationLabelVar
@@ -15,11 +16,9 @@ from nlp_tools.embeddings import ABCEmbedding,TransformerEmbedding,BertEmbedding
 from nlp_tools.optimizer import MultiOptimizer
 from tensorflow.keras.optimizers import Adam
 
-#from transformers.optimization_tf import AdamWeightDecay
+from transformers.optimization_tf import AdamWeightDecay
 from nlp_tools.loss.r_drop_loss import RDropLoss
 
-from nlp_tools.metrics.plot.confusion_seaborn import plot_confusion_mat
-
 class ABCClassificationModel(ABCTaskModel,ABC):
     """
     Abstract Classification Model
@@ -65,10 +64,9 @@ class ABCClassificationModel(ABCTaskModel,ABC):
 
         if loss is None:
             from nlp_tools.loss import multi_category_focal_loss2_fixed
-            from tensorflow.keras.losses import SparseCategoricalCrossentropy
-            from nlp_tools.loss import categorical_focal_loss
-            loss = SparseCategoricalCrossentropy()
-            #loss = multi_category_focal_loss2_fixed
+            from tensorflow.keras.losses import CategoricalCrossentropy
+            #loss = 'categorical_crossentropy'
+            loss = multi_category_focal_loss2_fixed
 
         if type(self.embedding) in [TransformerEmbedding, BertEmbedding]:
             total_layers = self.tf_model.layers
@@ -81,7 +79,7 @@ class ABCClassificationModel(ABCTaskModel,ABC):
             optimizers_and_layers = [(optimizer_list[0], no_transformer_layers), (optimizer_list[1], transfomer_layers)]
             optimizer = MultiOptimizer(optimizers_and_layers)
         else:
-            optimizer = Adam(1e-5)
+            optimizer = Adam()
         if self.use_rdrop:
             if type(loss) == list:
                 loss = [RDropLoss(i) for i in loss]
@@ -106,8 +104,7 @@ class ABCClassificationModel(ABCTaskModel,ABC):
                 batch_size: int = 32,
                 truncating: bool = False,
                 multi_label_threshold: float = 0.5,
-                predict_kwargs: Dict = None,
-                return_labels=True) -> Union[ClassificationLabelVar, MultiLabelClassificationLabelVar]:
+                predict_kwargs: Dict = None) -> Union[ClassificationLabelVar, MultiLabelClassificationLabelVar]:
         if predict_kwargs is None:
             predict_kwargs = {}
 
@@ -119,45 +116,35 @@ class ABCClassificationModel(ABCTaskModel,ABC):
             tensor = self.text_processor.transform(x_data,seq_length=seq_length)
             pred = self.tf_model.predict(tensor, batch_size=batch_size, **predict_kwargs)
             pred_argmax = pred.argmax(-1)
-            if return_labels:
-                res = self.label_processor.inverse_transform(pred_argmax)
-            else:
-                res = pred_argmax
+            res = self.label_processor.inverse_transform(pred_argmax)
 
         return res
 
     def evaluate(self,
-                 valid_data,
+                 x_data: TextSamplesVar,
+                 y_data: Union[ClassificationLabelVar, MultiLabelClassificationLabelVar],
                  *,
                  batch_size: int = 32,
                  digits: int = 4,
                  multi_label_threshold: float = 0.5,
-                 result_save_path = None):
-        x_data = [item[0] for item in valid_data]
-        y_data = [item[1] for item in valid_data]
-        y_pred_ids = self.predict(x_data,
+                 truncating: bool = False,) -> Dict:
+        y_pred = self.predict(x_data,
                               batch_size=batch_size,
-                              multi_label_threshold=multi_label_threshold,
-                              return_labels=False)
+                              truncating=truncating,
+                              multi_label_threshold=multi_label_threshold)
 
-        valid_y_ids = self.label_processor.transform([y for y in y_data])
-        label_names = [key for key in self.label_processor.vocab2idx.keys()]
 
-        original_report = sklearn_metrics.classification_report(valid_y_ids,
-                                                                y_pred_ids,
-                                                                digits=digits,
-                                                                target_names=label_names)
-        print(original_report)
-        if result_save_path:
-            if not os.path.exists(result_save_path):
-                os.mkdir(result_save_path)
-            confusion_save_path = os.path.join(result_save_path, 'confusion.jpg')
-            classify_report_path = os.path.join(result_save_path, 'classify_report.txt')
-            figure = plot_confusion_mat(valid_y_ids, y_pred_ids, label_names)
-            figure.savefig(confusion_save_path, dpi=600)
-
-            with open(classify_report_path,'w',encoding='utf-8') as fwrite:
-                if type(original_report) == dict:
-                    original_report = json.dumps(original_report,indent=4,ensure_ascii=False)
-                fwrite.write(original_report)
+        original_report = sklearn_metrics.classification_report(y_data,
+                                                                y_pred,
+                                                                output_dict=True,
+                                                                digits=digits)
+        print(sklearn_metrics.classification_report(y_data,
+                                                    y_pred,
+                                                    output_dict=False,
+                                                    digits=digits))
+        report = {
+            'detail': original_report,
+            **original_report['weighted avg']
+        }
+        return report
 
