@@ -28,7 +28,10 @@ from tensorflow.keras.optimizers import Adam
 from nlp_tools.utils.ner_utils import output_ner_results
 from nlp_tools.utils.training_tips import creat_FGM
 from nlp_tools.loss.r_drop_loss import RDropLoss
+from sklearn.model_selection._split import StratifiedKFold,KFold
+from tensorflow.keras import backend as K
 import functools
+import os
 
 
 
@@ -107,16 +110,19 @@ class ABCLabelingModel(ABCTaskModel, ABC):
                               generators: List[CorpusGenerator]) -> None:
 
         self.label_processor.build_vocab_generator(generators)
-        if self.train_max_sequence_length is None:
+        if self.train_max_sequence_length is None and self.text_processor:
             self.train_max_sequence_length = self.text_processor.get_max_seq_length_from_corpus(generators,cover_rate=1.0)
 
         if self.train_sequece_length_as_max_sequence_length:
             self.max_sequence_length = self.train_sequece_length_as_max_sequence_length
 
         self.label_processor.update_length_info(embedding_max_position=self.embedding_max_position,max_sentence_length=self.max_sequence_length)
-        self.text_processor.update_length_info(embedding_max_position=self.embedding_max_position,max_sentence_length=self.max_sequence_length)
 
-        self.embedding.build_embedding_model()
+        if self.text_processor:
+            self.text_processor.update_length_info(embedding_max_position=self.embedding_max_position,max_sentence_length=self.max_sequence_length)
+
+        if self.embedding:
+            self.embedding.build_embedding_model()
 
 
         if self.tf_model is None:
@@ -311,31 +317,33 @@ class ABCLabelingModel(ABCTaskModel, ABC):
 
     def ner_data_tokeninzed_and_change_label(self,data):
         '''对训练数据分词处理，并跟新label的index'''
-        tokenizer_data = []
-        for (x, y) in data:
-            item = []
-            tokens = self.text_processor.text_tokenizer.tokenize(x)
-            item.append(tokens)
+        if self.text_processor and hasattr(self.text_processor.text_tokenizer,'rematch'):
+            tokenizer_data = []
+            for (x, y) in data:
+                item = []
+                tokens = self.text_processor.text_tokenizer.tokenize(x)
+                item.append(tokens)
 
-            mapping = self.text_processor.text_tokenizer.rematch(x, tokens)
-            start_mapping = {j[0]: i for i, j in enumerate(mapping) if j}
-            end_mapping = {j[-1]: i for i, j in enumerate(mapping) if j}
+                mapping = self.text_processor.text_tokenizer.rematch(x, tokens)
+                start_mapping = {j[0]: i for i, j in enumerate(mapping) if j}
+                end_mapping = {j[-1]: i for i, j in enumerate(mapping) if j}
 
-            entities = []
-            for start, end ,label in y:
-                if start in start_mapping and end in end_mapping:
-                    start = start_mapping[start]
-                    end = end_mapping[end]
-                    entities.append((start,end,label))
-            item.append(entities)
+                entities = []
+                for start, end ,label in y:
+                    if start in start_mapping and end in end_mapping:
+                        start = start_mapping[start]
+                        end = end_mapping[end]
+                        entities.append((start,end,label))
+                item.append(entities)
 
-            tokenizer_data.append(item)
+                tokenizer_data.append(item)
+        else:
+            tokenizer_data = data
         return tokenizer_data
 
-    def smooth_labels(self,labels, factor=0.1):
+    def smooth_labels(self, labels, factor=0.1):
         # smooth the labels
         labels *= (1 - factor)
         labels += (factor / labels.shape[1])
 
-        # returned the smoothed labels
-        return labels
\ No newline at end of file
+        return labels
