@@ -11,7 +11,7 @@ class ABCTokenizer(ABC):
             'config':{}
         }
 
-    def tokenize(self, text: str):
+    def tokenize(self, text,max_len=None,**kwargs):
         """
         Tokenize text into token sequence
         Args:
@@ -22,6 +22,11 @@ class ABCTokenizer(ABC):
         """
         raise NotImplementedError
 
-    def encode(self,text,**kwargs):
+    def encode(self,text,
+                second_text=None,
+                maxlen=None,**kwargs):
         raise NotImplementedError
 
+    def id_to_token(self, id):
+        raise  NotImplementedError
+
